@@ -126,7 +126,8 @@ class Jira(AtlassianRestAPI):
 
     def get_issue_transitions(self, issuekey):
         url = '/rest/api/2/issue/{issuekey}?expand=transitions.fields&fields=status'.format(issuekey=issuekey)
-        return [{'name': transition['name'], 'id': int(transition['id']), 'to': transition['to']['name']} for transition in self.get(url)['transitions']]
+        return [{'name': transition['name'], 'id': int(transition['id']), 'to': transition['to']['name']}
+                for transition in self.get(url)['transitions']]
 
     def get_status_id_from_name(self, status_name):
         url = '/rest/api/2/status/{name}'.format(name=status_name)
